@@ -23,8 +23,7 @@
 
 #include <KontactInterface/UniqueAppHandler>
 
-namespace KontactInterface
-{
+namespace KontactInterface {
 class Plugin;
 }
 
@@ -33,9 +32,12 @@ class KAddressBookUniqueAppHandler : public KontactInterface::UniqueAppHandler
     Q_OBJECT
 public:
     explicit KAddressBookUniqueAppHandler(KontactInterface::Plugin *plugin)
-        : KontactInterface::UniqueAppHandler(plugin) {}
-    void loadCommandLineOptions(QCommandLineParser *parser) Q_DECL_OVERRIDE;
-    int activate(const QStringList &args, const QString &workingDir) Q_DECL_OVERRIDE;
+        : KontactInterface::UniqueAppHandler(plugin)
+    {
+    }
+
+    void loadCommandLineOptions(QCommandLineParser *parser) override;
+    int activate(const QStringList &args, const QString &workingDir) override;
 };
 
 class KAddressBookPlugin : public KontactInterface::Plugin
@@ -46,17 +48,17 @@ public:
     KAddressBookPlugin(KontactInterface::Core *core, const QVariantList &);
     ~KAddressBookPlugin();
 
-    bool isRunningStandalone() const Q_DECL_OVERRIDE;
-    int weight() const Q_DECL_OVERRIDE
+    bool isRunningStandalone() const override;
+    int weight() const override
     {
         return 300;
     }
 
-    QStringList invisibleToolbarActions() const Q_DECL_OVERRIDE;
-    void shortcutChanged() Q_DECL_OVERRIDE;
+    QStringList invisibleToolbarActions() const override;
+    void shortcutChanged() override;
 
 protected:
-    KParts::ReadOnlyPart *createPart() Q_DECL_OVERRIDE;
+    KParts::ReadOnlyPart *createPart() override;
 
 private Q_SLOTS:
     void slotNewContact();
@@ -64,8 +66,6 @@ private Q_SLOTS:
 
 private:
     KontactInterface::UniqueAppWatcher *mUniqueAppWatcher;
-
 };
 
 #endif
-
