@@ -26,13 +26,11 @@
 #include <QItemSelection>
 #include <QWidget>
 
-namespace GrantleeTheme
-{
+namespace GrantleeTheme {
 class ThemeManager;
 }
 class QAction;
-namespace Akonadi
-{
+namespace Akonadi {
 class Collection;
 class ContactGroupViewer;
 class ContactViewer;
@@ -43,18 +41,15 @@ class Item;
 class StandardContactActionManager;
 class EntityTreeModel;
 }
-namespace PimCommon
-{
+namespace PimCommon {
 class AbstractGenericPluginInterface;
 }
 
-namespace KAddressBookGrantlee
-{
+namespace KAddressBookGrantlee {
 class GrantleeContactFormatter;
 class GrantleeContactGroupFormatter;
 }
-namespace KAddressBookImportExport
-{
+namespace KAddressBookImportExport {
 class KAddressBookImportExportPluginManager;
 class KAddressBookImportExportPluginInterface;
 }
